@@ -1,9 +1,7 @@
-{-# LANGUAGE
-CPP,
-TemplateHaskell,
-RankNTypes,
-FlexibleContexts
-  #-}
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE TemplateHaskell #-}
+{-# LANGUAGE RankNTypes #-}
+{-# LANGUAGE FlexibleContexts #-}
 
 #ifndef MIN_VERSION_template_haskell
 #define MIN_VERSION_template_haskell(x,y,z) (defined(__GLASGOW_HASKELL__) && __GLASGOW_HASKELL__ >= 706)
@@ -372,7 +370,7 @@ instance HasY (Foo a) a where
   y = ...
 @
 
-(There's a minor drawback, tho: you can't perform type-changing updates with these lenses.)
+(There's a minor drawback, though: you can't perform type-changing updates with these lenses.)
 
 If you only want to make lenses for some fields, you can prefix them with underscores – the rest would be untouched. If no fields are prefixed with underscores, lenses would be created for all fields.
 
@@ -601,7 +599,7 @@ lensRules = LensRules
 A modification of 'lensRules' used by 'makeLensesFor' (the only difference is that a simple lookup function is used for 'lensField').
 -}
 lensRulesFor
-  :: [(String, String)] -- ^ \[(fieldName, lensName)\]
+  :: [(String, String)] -- ^ @[(fieldName, lensName)]@
   -> LensRules
 lensRulesFor fields = lensRules & lensField .~ mkNameLookup fields
 
